LogStore class
Stores collected logs in memory with a maximum capacity.
This class is used internally by MarionetteBinding to store logs received from a LogCollector.
Constructors
- LogStore()
Properties
Methods
-
add(
String log) → void - Adds a log entry to the store.
-
clear(
) → void - Clears all collected logs.
-
getLogs(
) → List< String> - Returns all collected logs as a list of strings.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited