TypeStringMatcher class
Matches widgets by their runtime type as a string.
- Inheritance
-
- Object
- WidgetMatcher
- TypeStringMatcher
Constructors
- TypeStringMatcher(String typeName)
-
const
-
TypeStringMatcher.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
matches(
Widget widget, MarionetteConfiguration configuration) → bool -
Checks if the given
widgetmatches this matcher's criteria.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this matcher to a JSON-serializable map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited